---
title: Spinners
description: Indicate the loading state of a component or page with Bootstrap spinners, built entirely with HTML, CSS, and no JavaScript.
toc: true
---

import { getData } from '@libs/data'

## About

Bootstrap “spinners” can be used to show the loading state in your projects. They’re built only with HTML and CSS, meaning you don’t need any JavaScript to create them. You will, however, need some custom JavaScript to toggle their visibility. Their appearance, alignment, and sizing can be easily customized with our amazing utility classes.

For accessibility purposes, each loader here includes `role="status"` and a nested `<span class="visually-hidden">Loading...</span>`.

<Callout name="info-prefersreducedmotion" />

## Border spinner

Use the border spinners for a lightweight loading indicator.

<Example code={`<div class="spinner-border" role="status">
    <span class="visually-hidden">Loading...</span>
  </div>`} />

### Colors

The border spinner uses `currentColor` for its `border-color`, meaning you can customize the color with [text color utilities][color]. You can use any of our text color utilities on the standard spinner.

<Example code={getData('theme-colors').map((themeColor) => `<div class="spinner-border text-${themeColor.name}" role="status">
    <span class="visually-hidden">Loading...</span>
  </div>`)} />

<Callout>
**Why not use `border-color` utilities?** Each border spinner specifies a `transparent` border for at least one side, so `.border-{color}` utilities would override that.
</Callout>

## Growing spinner

If you don’t fancy a border spinner, switch to the grow spinner. While it doesn’t technically spin, it does repeatedly grow!

<Example code={`<div class="spinner-grow" role="status">
    <span class="visually-hidden">Loading...</span>
  </div>`} />

Once again, this spinner is built with `currentColor`, so you can easily change its appearance with [text color utilities][color]. Here it is in blue, along with the supported variants.

<Example code={getData('theme-colors').map((themeColor) => `<div class="spinner-grow text-${themeColor.name}" role="status">
    <span class="visually-hidden">Loading...</span>
  </div>`)} />

## Alignment

Spinners in Bootstrap are built with `rem`s, `currentColor`, and `display: inline-flex`. This means they can easily be resized, recolored, and quickly aligned.

### Margin

Use [margin utilities][margin] like `.m-5` for easy spacing.

<Example code={`<div class="spinner-border m-5" role="status">
    <span class="visually-hidden">Loading...</span>
  </div>`} />

### Placement

Use [flexbox utilities][flex], [float utilities][float], or [text alignment][text] utilities to place spinners exactly where you need them in any situation.

#### Flex

<Example code={`<div class="d-flex justify-content-center">
    <div class="spinner-border" role="status">
      <span class="visually-hidden">Loading...</span>
    </div>
  </div>`} />

<Example code={`<div class="d-flex align-items-center">
    <strong role="status">Loading...</strong>
    <div class="spinner-border ms-auto" aria-hidden="true"></div>
  </div>`} />

#### Floats

<Example code={`<div class="clearfix">
    <div class="spinner-border float-end" role="status">
      <span class="visually-hidden">Loading...</span>
    </div>
  </div>`} />

#### Text align

<Example code={`<div class="text-center">
    <div class="spinner-border" role="status">
      <span class="visually-hidden">Loading...</span>
    </div>
  </div>`} />

## Size

Add `.spinner-border-sm` and `.spinner-grow-sm` to make a smaller spinner that can quickly be used within other components.

<Example code={`<div class="spinner-border spinner-border-sm" role="status">
    <span class="visually-hidden">Loading...</span>
  </div>
  <div class="spinner-grow spinner-grow-sm" role="status">
    <span class="visually-hidden">Loading...</span>
  </div>`} />

Or, use custom CSS or inline styles to change the dimensions as needed.

<Example code={`<div class="spinner-border" style="width: 3rem; height: 3rem;" role="status">
    <span class="visually-hidden">Loading...</span>
  </div>
  <div class="spinner-grow" style="width: 3rem; height: 3rem;" role="status">
    <span class="visually-hidden">Loading...</span>
  </div>`} />

## Buttons

Use spinners within buttons to indicate an action is currently processing or taking place. You may also swap the text out of the spinner element and utilize button text as needed.

<Example code={`<button class="btn btn-primary" type="button" disabled>
    <span class="spinner-border spinner-border-sm" aria-hidden="true"></span>
    <span class="visually-hidden" role="status">Loading...</span>
  </button>
  <button class="btn btn-primary" type="button" disabled>
    <span class="spinner-border spinner-border-sm" aria-hidden="true"></span>
    <span role="status">Loading...</span>
  </button>`} />

<Example code={`<button class="btn btn-primary" type="button" disabled>
    <span class="spinner-grow spinner-grow-sm" aria-hidden="true"></span>
    <span class="visually-hidden" role="status">Loading...</span>
  </button>
  <button class="btn btn-primary" type="button" disabled>
    <span class="spinner-grow spinner-grow-sm" aria-hidden="true"></span>
    <span role="status">Loading...</span>
  </button>`} />

## CSS

### Variables

<AddedIn version="5.2.0" />

As part of Bootstrap’s evolving CSS variables approach, spinners now use local CSS variables on `.spinner-border` and `.spinner-grow` for enhanced real-time customization. Values for the CSS variables are set via Sass, so Sass customization is still supported, too.

Border spinner variables:

<ScssDocs name="spinner-border-css-vars" file="scss/_spinners.scss" />

Growing spinner variables:

<ScssDocs name="spinner-grow-css-vars" file="scss/_spinners.scss" />

For both spinners, small spinner modifier classes are used to update the values of these CSS variables as needed. For example, the `.spinner-border-sm` class does the following:

<ScssDocs name="spinner-border-sm-css-vars" file="scss/_spinners.scss" />

### Sass variables

<ScssDocs name="spinner-variables" file="scss/_variables.scss" />

### Keyframes

Used for creating the CSS animations for our spinners. Included in `scss/_spinners.scss`.

<ScssDocs name="spinner-border-keyframes" file="scss/_spinners.scss" />

<ScssDocs name="spinner-grow-keyframes" file="scss/_spinners.scss" />


[color]:   [[docsref:/utilities/colors]]
[flex]:    [[docsref:/utilities/flex]]
[float]:   [[docsref:/utilities/float]]
[margin]:  [[docsref:/utilities/spacing]]
[text]:    [[docsref:/utilities/text]]
